@@ -311,7 +311,7 @@ class SQLAlchemyDatabase:
         *,
         threshold_for_copy: int = 100000,  # temporarily do not use copy
         returning_id: bool = False,
-        parallel: bool = False,
+        parallel_workers: int = 1,
     ) -> pl.DataFrame | None:
         """
         Validate a Polars DataFrame against the model schema, then delegate
@@ -327,12 +327,13 @@ class SQLAlchemyDatabase:
             return None
 
         if len(data) >= threshold_for_copy:
-            if parallel:
+            if parallel_workers > 1:
                 return self.handle_insertion_multi_line_copy_parallel(
                     model_class,
                     data,
                     mode,
                     returning_id=returning_id,
+                    num_workers=parallel_workers,
                 )
             return self.handle_insertion_multi_line_copy(
                 model_class,
@@ -707,7 +708,7 @@ class SQLAlchemyDatabase:
         mode: t.Literal["RAISE", "IGNORE", "UPDATE"],
         *,
         chunk_size: int = 1_000_000,
-        num_workers: int = 4,
+        num_workers: int = 2,
         returning_id: bool = False,
     ) -> pl.DataFrame | None:
         """
@@ -718,7 +719,6 @@ class SQLAlchemyDatabase:
         - For returning_id=True, collects results from all workers and combines them
 
         """
-        print("using parallel COPY")
         # Primary-key columns used for conflict detection
         pks = self.get_primary_unique_constraint(model_class)
         table = model_class.__table__.name
@@ -901,8 +901,6 @@ def _copy_worker_static(
     try:
         # Connection tuning for bulk operations
         cursor.execute("SET synchronous_commit = OFF")
-        cursor.execute("SET wal_buffers = '16MB'")
-        cursor.execute("SET checkpoint_completion_target = 0.9")
 
         # Precompute ON CONFLICT clause based on mode
         conflict_cols = ", ".join(f'"{c}"' for c in pks)
