@@ -520,62 +520,60 @@ class DataValidator:
             msg = f"Unknown countries in time_region_feature_data: {missing_countries}."
             raise ValueError(msg)
 
-        # Validate region-level combinations
-        if "level" in time_region_feature_map.columns and "region" in time_region_feature_map.columns:
-            region_level_df = time_region_feature_map.select(["region", "level", "country"]).unique()
-            region_level_values = region_level_df.rows()
+        region_level_df = time_region_feature_map.select(["region", "level", "country"]).unique()
+        region_level_values = region_level_df.rows()
 
-            # Query database regions with this type (level), joining with countries to get abbreviations
-            # We need to join Regions table with itself to get country abbreviations
-            country_region = aliased(Regions)
+        # Query database regions with this type (level), joining with countries to get abbreviations
+        # We need to join Regions table with itself to get country abbreviations
+        country_region = aliased(Regions)
 
-            db_regions = self.session.execute(
-                select(
-                    Regions.abbreviation.label("region_abbrev"),
-                    Regions.type.label("region_type"),
-                    country_region.abbreviation.label("country_abbrev"),
-                )
-                .join(country_region, Regions.country == country_region.id)
-                .where(country_region.type == "country")
-            ).all()
+        db_regions = self.session.execute(
+            select(
+                Regions.abbreviation.label("region_abbrev"),
+                Regions.type.label("region_type"),
+                country_region.abbreviation.label("country_abbrev"),
+            )
+            .join(country_region, Regions.country == country_region.id)
+            .where(country_region.type == "country")
+        ).all()
 
-            # Create valid combinations: {(region_abbrev, region_type, country_abbrev)}
-            db_valid_combinations = {(region, level, country) for region, level, country in db_regions}
+        # Create valid combinations: {(region_abbrev, region_type, country_abbrev)}
+        db_valid_combinations = {(region, level, country) for region, level, country in db_regions}
 
-            # Get all region abbreviations and levels from database
-            db_region_abbrevs = {region for region, _, _ in db_regions}
-            db_levels = {level for _, level, _ in db_regions}
+        # Get all region abbreviations and levels from database
+        db_region_abbrevs = {region for region, _, _ in db_regions}
+        db_levels = {level for _, level, _ in db_regions}
 
-            # Check for invalid regions
-            region_values = region_level_df.select("region").unique().to_series().to_list()
-            missing_regions = sorted(set(region_values) - db_region_abbrevs)
+        # Check for invalid regions
+        region_values = region_level_df.select("region").unique().to_series().to_list()
+        missing_regions = sorted(set(region_values) - db_region_abbrevs)
 
-            # Check for invalid levels
-            level_values = region_level_df.select("level").unique().to_series().to_list()
-            missing_levels = sorted(set(level_values) - db_levels)
+        # Check for invalid levels
+        level_values = region_level_df.select("level").unique().to_series().to_list()
+        missing_levels = sorted(set(level_values) - db_levels)
 
-            # Check for invalid (region, level, country) combinations
-            mismatched_combinations = [
-                (region, level, country)
-                for region, level, country in region_level_values
-                if region in db_region_abbrevs
-                and level in db_levels
-                and (region, level, country) not in db_valid_combinations
-            ]
+        # Check for invalid (region, level, country) combinations
+        mismatched_combinations = [
+            (region, level, country)
+            for region, level, country in region_level_values
+            if region in db_region_abbrevs
+            and level in db_levels
+            and (region, level, country) not in db_valid_combinations
+        ]
 
-            messages = []
-            if missing_regions:
-                messages.append(f"Invalid region values (not found in database): {missing_regions}")
+        messages = []
+        if missing_regions:
+            messages.append(f"Invalid region values (not found in database): {missing_regions}")
 
-            if missing_levels:
-                messages.append(f"Invalid level values (not found in database): {missing_levels}")
+        if missing_levels:
+            messages.append(f"Invalid level values (not found in database): {missing_levels}")
 
-            if mismatched_combinations:
-                formatted = "\n".join(f"- {r} / {lvl} / {c}" for r, lvl, c in mismatched_combinations)
-                messages.append(f"Invalid (region, level, country) combinations:\n{formatted}")
+        if mismatched_combinations:
+            formatted = "\n".join(f"- {r} / {lvl} / {c}" for r, lvl, c in mismatched_combinations)
+            messages.append(f"Invalid (region, level, country) combinations:\n{formatted}")
 
-            if messages:
-                raise ValueError("\n\n".join(messages))
+        if messages:
+            raise ValueError("\n\n".join(messages))
 
         logger.info("Check on time_region_feature_data passed.")
 
